"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.execSql = void 0;
const promisified_tedious_1 = require("promisified-tedious");
const DEBUG = false;
function debugLogs(msg) {
    if (DEBUG) {
        console.log(msg);
    }
}
function execSql(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const config = args.config;
        debugLogs('DB: ' + config.options.database);
        const connection = new promisified_tedious_1.Connection(config);
        try {
            debugLogs('connecting...');
            yield connection.connect();
        }
        catch (err) {
            console.error(err);
            return;
        }
        try {
            const request = new promisified_tedious_1.Request(args.query);
            debugLogs('About to run the query: ' + args.query);
            const result = yield connection.execSql(request);
            return flattenResult(result);
        }
        catch (err) {
            console.error(err);
        }
        finally {
            yield connection.close();
        }
    });
}
exports.execSql = execSql;
function flattenResult(response) {
    let result = new Array();
    const flatten = (r) => (Array.isArray(r) && r.length === 1 ? flatten(r[0]) : r);
    if (response) {
        for (let i in response) {
            result.push(new Array());
            for (let j in response[i]) {
                result[i].push(response[i][j].value);
            }
        }
        result = flatten(result);
    }
    else {
        result = response;
    }
    debugLogs(result);
    return result;
}
